{
  description = "Spacy-server flake";

  inputs.flake-utils.url = "github:numtide/flake-utils";
  inputs.nixpkgs.url = "github:NixOS/nixpkgs/nixos-unstable";

  outputs = { self, nixpkgs, flake-utils }:
    flake-utils.lib.eachDefaultSystem (system:
      let pkgs = nixpkgs.legacyPackages.${system};
          python = (pkgs.python3.override {
            packageOverrides = self: super: {
              sense2vec = self.buildPythonPackage rec {
                pname = "sense2vec" ;
                version = "2.0.2" ;
                src = pkgs.fetchFromGitHub {
                  owner = "explosion" ;
                  repo = "sense2vec";
                  rev = "v${version}";
                  sha256 = "sha256-o862emhbYEaIhzI3H4XDc7SjpDAQ05gL8BhSSW/KNE0=";
                };
              };
            };
          });
          ppkgs = model: pp: [ pp.fastapi
                               pp.ipython
                               pp.sense2vec
                               pp.spacy
                               pp.spacy-models."${model}"
                               pp.uvicorn ];
          pythonWithModel = model:
            python.withPackages (ppkgs model);

          server = model: (
            let pwm = pythonWithModel model;
            in
              pkgs.stdenv.mkDerivation rec {
                name = "server-${model}";
                src = ./.;
                buildInputs = [
                  pkgs.openblas
                  pwm
                ];
                nativeBuildInputs = [ pkgs.makeWrapper ];
                installPhase = with pwm.pkgs; ''
                  mkdir -p $out/bin
                  makeWrapper ${src}/startServer.sh $out/bin/startServer.sh \
                    --set PYTHONPATH "${pwm}/${pwm.sitePackages}" 
                '';
              }
          );

          langMap = {
            de = "de_dep_news_trf";
            el = "el_core_web_trf";
            en = "en_core_web_trf";
            es = "es_core_news_trf";
            fr = "fr_dep_news_trf";
            it = "it_core_news_trf";
            pl = "pl_core_news_trf";
            pt = "pt_core_news_trf";
            ru = "ru_core_news_trf";
            uk = "uk_core_news_trf";
            zh = "zh_core_news_trf";
          };

          mkSpacyDerivation = lang:
            pkgs.stdenv.mkDerivation {
              name = "spacy-${lang}";
              # no src, see
              # https://github.com/NixOS/nixpkgs/issues/23099
              dontUnpack = true;
              buildInputs = [
                (pythonWithModel (langMap."${lang}"))
                (server (langMap."${lang}"))
              ];
              installPhase = ''
                touch $out
              '';
            };

          mkDevShell = lang: pkgs.mkShell {
            buildInputs = [
              (pythonWithModel (langMap."${lang}"))
              (server (langMap."${lang}"))
            ];
            shellHook = ''
              ${(server (langMap."${lang}"))}/bin/startServer.sh
            '';
          };
      in
        {
          devShells.en = mkDevShell "en";
          devShells.fr = mkDevShell "fr";

          packages.en = mkSpacyDerivation "en";
          packages.fr = mkSpacyDerivation "fr" ;

          apps.en = flake-utils.lib.mkApp {
            drv = pkgs.writeShellApplication {
              name = "spacy-en";
              text = ''
                set -x
                ${(server (langMap."en"))}/bin/startServer.sh
              '';
            };
          };
        }
    );
}
